@@ -55,6 +55,7 @@ wfs_request *wfs_request_init()
   wr->resulttype = NULL;
   wr->sortby = NULL;
   wr->sections = NULL;
+  wr->callback = NULL;
 
   wr->insert_results = NULL;
   wr->delete_results = 0;
@@ -150,6 +151,12 @@ void wfs_request_flush(wfs_request * wr, FILE * output)
     fprintf(output, "\n");
   }
 
+  if (wr->callback) {
+    fprintf(output, " callback -> ");
+    buffer_flush(wr->callback, output);
+    fprintf(output, "\n");
+  }
+
   fprintf(output, "]\n");
 }
 #endif
@@ -174,6 +181,7 @@ void wfs_request_free(wfs_request * wr)
   if (wr->sortby)         buffer_free(wr->sortby);
   if (wr->sections)       list_free(wr->sections);
   if (wr->insert_results) alist_free(wr->insert_results);
+  if (wr->callback)       buffer_free(wr->callback);
 
   free(wr);
   wr = NULL;
@@ -253,7 +261,7 @@ static list *wfs_request_check_typename(ows * o, wfs_request * wr, list * layer_
  */
 static list *wfs_request_check_fid(ows * o, wfs_request * wr, list * layer_name)
 {
-  list *fe;
+  list *fe, *ff;
   mlist *f;
   buffer *b, *layer;
   list_node *ln, *ln_tpn;
@@ -302,7 +310,9 @@ static list *wfs_request_check_fid(ows * o, wfs_request * wr, list * layer_name)
         return NULL;
       }
 
-      layer = ows_layer_no_uri_to_uri(o->layers, fe->last->value);
+      ff = list_split(':', fe->last->value, false);
+      layer = ows_layer_no_uri_to_uri(o->layers, ff->last->value);
+      list_free(ff);
 
       /* If typename is NULL, fill the layer name list */
       if (!wr->typename && !in_list(layer_name, layer))
@@ -389,15 +399,9 @@ static void wfs_request_check_srs(ows * o, wfs_request * wr, list * layer_name)
       return;
     }
 
-    if ((wr->format == WFS_GML311 || wr->format == WFS_GML321) && wr->srs->is_degree) {
-      wr->srs->is_reverse_axis = true;
-      wr->srs->is_long = true;
-    } else if (wr->format == WFS_GML311 || wr->format == WFS_GML321) {
-      wr->srs->is_long = true;
-    } else if (ows_version_get(o->request->version) == 110 && wr->srs->is_degree) {
-      wr->srs->is_reverse_axis = true;
-      wr->srs->is_long = true;
-    } else if (ows_version_get(o->request->version) == 110) {
+    if (wr->format == WFS_GML311 || wr->format == WFS_GML321 ||
+        ows_version_get(o->request->version) == 110) {
+      wr->srs->honours_authority_axis_order = true;
       wr->srs->is_long = true;
     }
 
@@ -419,6 +423,7 @@ static void wfs_request_check_bbox(ows * o, wfs_request * wr, list * layer_name)
 {
   buffer *b;
   int srid = 4326; /* Default srid if not srs is provided since WFS 1.1.0 */
+  bool honours_authority_axis_order_if_no_explicit_srs = false;
 
   assert(o && wr && layer_name && wr->srs);
 
@@ -427,18 +432,16 @@ static void wfs_request_check_bbox(ows * o, wfs_request * wr, list * layer_name)
   b = array_get(o->cgi, "bbox");
   wr->bbox = ows_bbox_init();
 
-  if (ows_version_get(o->request->version) == 100) srid = wr->srs->srid;
+  if (ows_version_get(o->request->version) == 100)
+      srid = wr->srs->srid;
+  else
+      honours_authority_axis_order_if_no_explicit_srs = true;
 
-  if (!ows_bbox_set_from_str(o, wr->bbox, b->buf, srid)) {
+  if (!ows_bbox_set_from_str(o, wr->bbox, b->buf, srid, honours_authority_axis_order_if_no_explicit_srs)) {
     ows_error(o, OWS_ERROR_INVALID_PARAMETER_VALUE,
               "Bad parameters for Bbox, must be Xmin,Ymin,Xmax,Ymax[,crsuri]", "NULL");
     return;
   }
-
-  /* related to BBOX with crsuri and srsName issue like:
-     bbox=34.94,-10.52,71.96,32.19,urn:ogc:def:crs:EPSG::4326
-  */
-  if (wr->srs->is_reverse_axis) wr->bbox->srs->is_reverse_axis = true;
 }
 
 
@@ -465,6 +468,17 @@ static void wfs_request_check_output(ows * o, wfs_request * wr)
     else if (    buffer_cmp(array_get(o->cgi, "outputformat"), "JSON")
               || buffer_cmp(array_get(o->cgi, "outputformat"), "application/json"))
       wr->format = WFS_GEOJSON;
+    else if (    buffer_cmp(array_get(o->cgi, "outputformat"), "JSONP")
+              || buffer_cmp(array_get(o->cgi, "outputformat"), "application/javascript"))
+    {
+      wr->format = WFS_JSONP;
+
+      wr->callback = buffer_init();
+      if (!array_is_key(o->cgi, "callback"))
+          buffer_add_str(wr->callback, "wfs_jsonp_callback");
+      else 
+          buffer_copy(wr->callback, array_get(o->cgi, "callback"));
+    }
     else if (    wr->request == WFS_DESCRIBE_FEATURE_TYPE
               && buffer_cmp(array_get(o->cgi, "outputformat"), "XMLSCHEMA"))  // FIXME: really ?
       wr->format = WFS_XML_SCHEMA;
@@ -472,6 +486,9 @@ static void wfs_request_check_output(ows * o, wfs_request * wr)
       wfs_error(o, wr, WFS_ERROR_OUTPUT_FORMAT_NOT_SUPPORTED,
                 "OutputFormat is not supported", "GetFeature");
   }
+
+
+
 }
 
 
